"""Ferda hooks implementation."""

from collections.abc import Iterable
from typing import Any

import ferda

from ferda_pain.settings import SETTINGS

_PERMISSIONS = (
    ("ferda_pain.can_view", "Can view PAIN module"),
    ("ferda_pain.can_view_import", "Can view bank statement import"),
    ("ferda_pain.can_edit_account", "Can manipulate account"),
    ("ferda_pain.can_edit_payment", "Can manipulate payment"),
    ("ferda_pain.can_edit_prequest", "Can manipulate payment request"),
    ("ferda_pain.can_maintain", "Can carry out maintenance tasks"),
)


@ferda.hookimpl
def create_permissions() -> Iterable[tuple[str, str]]:
    """Create ferda-pain permissions."""
    return _PERMISSIONS


@ferda.hookimpl
def show_settings() -> dict[str, Any]:
    """Return context variables with ferda-pain settings."""
    context = {
        "pain": {
            "api_url": SETTINGS.api_url,
        }
    }
    return context
