"""Ferda-pain settings."""

from appsettings import AppSettings, PositiveFloatSetting, StringSetting
from django.core.exceptions import ValidationError
from django.core.validators import URLValidator


def http_with_slash_validator(value: str) -> None:
    """Validate string to be HTTP(S) based URL with trailing slash."""
    URLValidator(schemes=["http", "https"])(value)
    if not value.endswith("/"):
        raise ValidationError("Missing trailing slash")


class FerdaPainSettings(AppSettings):
    """Ferda-pain settings."""

    api_url = StringSetting(required=True, validators=[http_with_slash_validator])
    api_token = StringSetting(default=None)
    api_timeout = PositiveFloatSetting(default=3.05)  # in seconds
    ca_certs = StringSetting(default="/etc/ssl/certs/ca-certificates.crt")

    class Meta:
        """Meta class."""

        setting_prefix = "ferda_pain_"


SETTINGS = FerdaPainSettings()
