"""Tests of plugin settings."""

from django.core.exceptions import ValidationError
from django.test import SimpleTestCase

from ferda_pain.settings import http_with_slash_validator


class HttpWithSlashValidatorTest(SimpleTestCase):
    """Test web link validator."""

    def test_ok(self):
        data = ["http://www.example.org/path/", "https://www.example.org/path/"]
        for value in data:
            with self.subTest(value=value):
                http_with_slash_validator(value)

    def test_validation_fail(self):
        data = [
            "ftp://www.example.org/path/",  # bad scheme
            "www.example.org/path/",  # no scheme
            "http://",  # only scheme
            "http://www.example.org/path",  # missing trailing slash
        ]
        for value in data:
            with self.subTest(value=value):
                with self.assertRaises(ValidationError):
                    http_with_slash_validator(value)
